Keen | Charts
Description: Chart based widgets

# Customer Relationship Management

New Order

### Charts

Reports

### Author Sales

$64M

### Technologies

9.3M
HTML
CSS
Angular
+37%

### Total Orders

17M
New Customers
28 Daily Avr
+958
Weekly Orders
122 Daily Avr
7,300
Sales Increase
92 Daily Avr
75%

### Author Sales

$64M

### Technologies

9.3M
HTML
CSS
Angular
+37%

### Total Orders

17M

### Top Products

HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Freebie Themes
Font-end & Admin
+34
UI/UX Design
Evrything you ever imagine
+4%
HTML 5 Templates
Font-end,Admin & Email
+79%
Wordpress Themes
eCommerce Website, Plugin
+21%
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
Freebie Themes
Font-end & Admin
+34
eCommerce Websites
Shops, Fasion wep sites & atc
-16%
UI/UX Design
Evrything you ever imagine
+4%
Latest Trends
eCommerce Website, Plugin
+34%
HTML 5 Templates
Font-end,Admin & Email
+79%
Freebie Themes
Font-end & Admin
+34

### Sales Statistics

Author
Customer

### Revenue Growth

Author
Customer

### Top Categories

Templates
Front-end, Admin
5.7k
+780
Wordpress
eCommerce, Website
2.8k
+350
eCommerce
Fashion Websites
9.3k
+2.1k
UI/UX Design
Everything you like
9.3k
+1.6k
SAAS Solution
Monthly Subscription
5.7k
+598

### General Statistics

XML CSV
Sales
USP:
+23%
Products
MRT:
+10%
Profit
FTP:
+19%
Reports
RNP:
+30%
Author Sales
Product Profit

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!